==> bark_simulator-0.0.5-py3-none-any.whl: bark/runtime/viewer/video_renderer.py <==
# Copyright (c) 2019 fortiss GmbH
#
# This software is released under the MIT License.
# https://opensource.org/licenses/MIT

import tempfile
import os
import shutil
import uuid

from bark.pybark.core.geometry import *
from bark.pybark.core.viewer import *
from bark.pybark.core.models.dynamic import *
from bark.runtime.viewer.viewer import BaseViewer


class VideoRenderer(BaseViewer):
    def __init__(self, renderer, world_step_time, render_intermediate_steps=None , params=None, video_name=None, fig_path=None, clear_figures=True, **kwargs):
        super(VideoRenderer, self).__init__(params=params)
        self.renderer = renderer
        self.world_step_time = world_step_time
        self.render_intermediate_steps = render_intermediate_steps

        video_dir_name = "vid_render_frames_{}".format(uuid.uuid4()) if video_name is None else video_name
        self.fig_path = fig_path if fig_path is not None else tempfile.gettempdir()
        self.video_frame_dir = os.path.join(self.fig_path, video_dir_name)
        if clear_figures and os.path.exists(self.video_frame_dir):
            print("video path already exists, clear existing one")
            self.reset()
        os.makedirs(self.video_frame_dir, exist_ok=True)

        self.frame_count = 0

    def drawWorld(self, world, eval_agent_ids=None, scenario_idx=None, debug_text=False):
        if self.render_intermediate_steps is None:
            self._renderWorld(world, eval_agent_ids, scenario_idx)
        else:
            world_time = world.time
            executed_world = world
            for _ in range(0,self.render_intermediate_steps):
                executed_world = executed_world.WorldExecutionAtTime(world_time)
                self._renderWorld(executed_world, eval_agent_ids, scenario_idx)
                world_time = world_time + self.world_step_time/self.render_intermediate_steps

    def drawText(self, **kwargs):
        self.renderer.drawText(**kwargs)

    def _renderWorld(self, world, eval_agent_ids=None, scenario_idx=None, debug_text=False):
        image_path = os.path.join(self.video_frame_dir, "{}.png".format(self.frame_count))
        self.renderer.drawWorld(world=world, eval_agent_ids=eval_agent_ids,
                                filename=image_path, scenario_idx=scenario_idx, debug_text=debug_text)
        self.frame_count = self.frame_count + 1

    def reset(self):
        shutil.rmtree(os.path.abspath(self.video_frame_dir))

    def export_video(self, filename, remove_image_dir=True):
        if self.render_intermediate_steps is None:
            framerate = 1/self.world_step_time
        else:
            framerate =  1/(self.world_step_time/self.render_intermediate_steps)

        if os.path.isfile(filename):
            os.remove(filename)
        if not os.path.exists(os.path.dirname(filename)):
            os.makedirs(os.path.dirname(filename))
        cmd = "ffmpeg -y -framerate {} -i \'{}/%01d.png\' -vcodec h264 -force_key_frames 'expr:gte(t,n_forced*{})' -acodec pcm_s16le -s 1920x1080 -r 30 -b:v 36M -pix_fmt yuv420p -f mp4 \'{}.mp4\'".format(
            framerate, self.video_frame_dir, 1 / framerate, os.path.abspath(filename))
        os.system(cmd)

        if remove_image_dir:
            shutil.rmtree(os.path.abspath(self.video_frame_dir))

    def clear(self):
      self.renderer.clear()

==> bark_simulator-0.0.6-py3-none-any.whl: bark/runtime/viewer/video_renderer.py <==
# Copyright (c) 2019 fortiss GmbH
#
# This software is released under the MIT License.
# https://opensource.org/licenses/MIT

import tempfile
import os
import shutil
import uuid

from bark.core.geometry import *
from bark.core.viewer import *
from bark.core.models.dynamic import *
from bark.runtime.viewer.viewer import BaseViewer


class VideoRenderer(BaseViewer):
    def __init__(self, renderer, world_step_time, render_intermediate_steps=None , params=None, video_name=None, fig_path=None, clear_figures=True, **kwargs):
        super(VideoRenderer, self).__init__(params=params)
        self.renderer = renderer
        self.world_step_time = world_step_time
        self.render_intermediate_steps = render_intermediate_steps

        video_dir_name = "vid_render_frames_{}".format(uuid.uuid4()) if video_name is None else video_name
        self.fig_path = fig_path if fig_path is not None else tempfile.gettempdir()
        self.video_frame_dir = os.path.join(self.fig_path, video_dir_name)
        if clear_figures and os.path.exists(self.video_frame_dir):
            print("video path already exists, clear existing one")
            self.reset()
        os.makedirs(self.video_frame_dir, exist_ok=True)

        self.frame_count = 0

    def drawWorld(self, world, eval_agent_ids=None, scenario_idx=None, debug_text=False):
        if self.render_intermediate_steps is None:
            self._renderWorld(world, eval_agent_ids, scenario_idx)
        else:
            world_time = world.time
            executed_world = world
            for _ in range(0,self.render_intermediate_steps):
                executed_world = executed_world.WorldExecutionAtTime(world_time)
                self._renderWorld(executed_world, eval_agent_ids, scenario_idx)
                world_time = world_time + self.world_step_time/self.render_intermediate_steps

    def drawText(self, **kwargs):
        self.renderer.drawText(**kwargs)

    def _renderWorld(self, world, eval_agent_ids=None, scenario_idx=None, debug_text=False):
        image_path = os.path.join(self.video_frame_dir, "{}.png".format(self.frame_count))
        self.renderer.drawWorld(world=world, eval_agent_ids=eval_agent_ids,
                                filename=image_path, scenario_idx=scenario_idx, debug_text=debug_text)
        self.frame_count = self.frame_count + 1

    def reset(self):
        shutil.rmtree(os.path.abspath(self.video_frame_dir))

    def export_video(self, filename, remove_image_dir=True):
        if self.render_intermediate_steps is None:
            framerate = 1/self.world_step_time
        else:
            framerate =  1/(self.world_step_time/self.render_intermediate_steps)

        if os.path.isfile(filename):
            os.remove(filename)
        if not os.path.exists(os.path.dirname(filename)):
            os.makedirs(os.path.dirname(filename))
        cmd = "ffmpeg -y -framerate {} -i \'{}/%01d.png\' -vcodec h264 -force_key_frames 'expr:gte(t,n_forced*{})' -acodec pcm_s16le -s 1920x1080 -r 30 -b:v 36M -pix_fmt yuv420p -f mp4 \'{}.mp4\'".format(
            framerate, self.video_frame_dir, 1 / framerate, os.path.abspath(filename))
        os.system(cmd)

        if remove_image_dir:
            shutil.rmtree(os.path.abspath(self.video_frame_dir))

    def clear(self):
      self.renderer.clear()
